Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppsV1Client ¶
type AppsV1Client struct {
// contains filtered or unexported fields
}
AppsV1Client is used to interact with features provided by the apps.openshift.io group.
func New ¶
func New(c rest.Interface) *AppsV1Client
New creates a new AppsV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AppsV1Client, error)
NewForConfig creates a new AppsV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new AppsV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AppsV1Client
NewForConfigOrDie creates a new AppsV1Client for the given config and panics if there is an error in the config.
func (*AppsV1Client) DeploymentConfigs ¶
func (c *AppsV1Client) DeploymentConfigs(namespace string) DeploymentConfigInterface
func (*AppsV1Client) RESTClient ¶
func (c *AppsV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type AppsV1Interface ¶
type AppsV1Interface interface {
RESTClient() rest.Interface
DeploymentConfigsGetter
}
type DeploymentConfigExpansion ¶
type DeploymentConfigExpansion interface{}
type DeploymentConfigInterface ¶
type DeploymentConfigInterface interface {
Create(ctx context.Context, deploymentConfig *appsv1.DeploymentConfig, opts metav1.CreateOptions) (*appsv1.DeploymentConfig, error)
Update(ctx context.Context, deploymentConfig *appsv1.DeploymentConfig, opts metav1.UpdateOptions) (*appsv1.DeploymentConfig, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, deploymentConfig *appsv1.DeploymentConfig, opts metav1.UpdateOptions) (*appsv1.DeploymentConfig, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*appsv1.DeploymentConfig, error)
List(ctx context.Context, opts metav1.ListOptions) (*appsv1.DeploymentConfigList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *appsv1.DeploymentConfig, err error)
Apply(ctx context.Context, deploymentConfig *applyconfigurationsappsv1.DeploymentConfigApplyConfiguration, opts metav1.ApplyOptions) (result *appsv1.DeploymentConfig, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, deploymentConfig *applyconfigurationsappsv1.DeploymentConfigApplyConfiguration, opts metav1.ApplyOptions) (result *appsv1.DeploymentConfig, err error)
Instantiate(ctx context.Context, deploymentConfigName string, deploymentRequest *appsv1.DeploymentRequest, opts metav1.CreateOptions) (*appsv1.DeploymentConfig, error)
Rollback(ctx context.Context, deploymentConfigName string, deploymentConfigRollback *appsv1.DeploymentConfigRollback, opts metav1.CreateOptions) (*appsv1.DeploymentConfig, error)
GetScale(ctx context.Context, deploymentConfigName string, options metav1.GetOptions) (*v1beta1.Scale, error)
UpdateScale(ctx context.Context, deploymentConfigName string, scale *v1beta1.Scale, opts metav1.UpdateOptions) (*v1beta1.Scale, error)
DeploymentConfigExpansion
}
DeploymentConfigInterface has methods to work with DeploymentConfig resources.
type DeploymentConfigsGetter ¶
type DeploymentConfigsGetter interface {
DeploymentConfigs(namespace string) DeploymentConfigInterface
}
DeploymentConfigsGetter has a method to return a DeploymentConfigInterface. A group's client should implement this interface.