Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type AuthorizationV1Client
- func (c *AuthorizationV1Client) ClusterRoleBindings() ClusterRoleBindingInterface
- func (c *AuthorizationV1Client) ClusterRoles() ClusterRoleInterface
- func (c *AuthorizationV1Client) LocalResourceAccessReviews(namespace string) LocalResourceAccessReviewInterface
- func (c *AuthorizationV1Client) LocalSubjectAccessReviews(namespace string) LocalSubjectAccessReviewInterface
- func (c *AuthorizationV1Client) RESTClient() rest.Interface
- func (c *AuthorizationV1Client) ResourceAccessReviews() ResourceAccessReviewInterface
- func (c *AuthorizationV1Client) RoleBindingRestrictions(namespace string) RoleBindingRestrictionInterface
- func (c *AuthorizationV1Client) RoleBindings(namespace string) RoleBindingInterface
- func (c *AuthorizationV1Client) Roles(namespace string) RoleInterface
- func (c *AuthorizationV1Client) SelfSubjectRulesReviews(namespace string) SelfSubjectRulesReviewInterface
- func (c *AuthorizationV1Client) SubjectAccessReviews() SubjectAccessReviewInterface
- func (c *AuthorizationV1Client) SubjectRulesReviews(namespace string) SubjectRulesReviewInterface
- type AuthorizationV1Interface
- type ClusterRoleBindingExpansion
- type ClusterRoleBindingInterface
- type ClusterRoleBindingsGetter
- type ClusterRoleExpansion
- type ClusterRoleInterface
- type ClusterRolesGetter
- type LocalResourceAccessReviewExpansion
- type LocalResourceAccessReviewInterface
- type LocalResourceAccessReviewsGetter
- type LocalSubjectAccessReviewExpansion
- type LocalSubjectAccessReviewInterface
- type LocalSubjectAccessReviewsGetter
- type ResourceAccessReviewExpansion
- type ResourceAccessReviewInterface
- type ResourceAccessReviewsGetter
- type RoleBindingExpansion
- type RoleBindingInterface
- type RoleBindingRestrictionExpansion
- type RoleBindingRestrictionInterface
- type RoleBindingRestrictionsGetter
- type RoleBindingsGetter
- type RoleExpansion
- type RoleInterface
- type RolesGetter
- type SelfSubjectRulesReviewExpansion
- type SelfSubjectRulesReviewInterface
- type SelfSubjectRulesReviewsGetter
- type SubjectAccessReviewExpansion
- type SubjectAccessReviewInterface
- type SubjectAccessReviewsGetter
- type SubjectRulesReviewExpansion
- type SubjectRulesReviewInterface
- type SubjectRulesReviewsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthorizationV1Client ¶
type AuthorizationV1Client struct {
// contains filtered or unexported fields
}
AuthorizationV1Client is used to interact with features provided by the authorization.openshift.io group.
func New ¶
func New(c rest.Interface) *AuthorizationV1Client
New creates a new AuthorizationV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AuthorizationV1Client, error)
NewForConfig creates a new AuthorizationV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new AuthorizationV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AuthorizationV1Client
NewForConfigOrDie creates a new AuthorizationV1Client for the given config and panics if there is an error in the config.
func (*AuthorizationV1Client) ClusterRoleBindings ¶
func (c *AuthorizationV1Client) ClusterRoleBindings() ClusterRoleBindingInterface
func (*AuthorizationV1Client) ClusterRoles ¶
func (c *AuthorizationV1Client) ClusterRoles() ClusterRoleInterface
func (*AuthorizationV1Client) LocalResourceAccessReviews ¶
func (c *AuthorizationV1Client) LocalResourceAccessReviews(namespace string) LocalResourceAccessReviewInterface
func (*AuthorizationV1Client) LocalSubjectAccessReviews ¶
func (c *AuthorizationV1Client) LocalSubjectAccessReviews(namespace string) LocalSubjectAccessReviewInterface
func (*AuthorizationV1Client) RESTClient ¶
func (c *AuthorizationV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*AuthorizationV1Client) ResourceAccessReviews ¶
func (c *AuthorizationV1Client) ResourceAccessReviews() ResourceAccessReviewInterface
func (*AuthorizationV1Client) RoleBindingRestrictions ¶
func (c *AuthorizationV1Client) RoleBindingRestrictions(namespace string) RoleBindingRestrictionInterface
func (*AuthorizationV1Client) RoleBindings ¶
func (c *AuthorizationV1Client) RoleBindings(namespace string) RoleBindingInterface
func (*AuthorizationV1Client) Roles ¶
func (c *AuthorizationV1Client) Roles(namespace string) RoleInterface
func (*AuthorizationV1Client) SelfSubjectRulesReviews ¶
func (c *AuthorizationV1Client) SelfSubjectRulesReviews(namespace string) SelfSubjectRulesReviewInterface
func (*AuthorizationV1Client) SubjectAccessReviews ¶
func (c *AuthorizationV1Client) SubjectAccessReviews() SubjectAccessReviewInterface
func (*AuthorizationV1Client) SubjectRulesReviews ¶
func (c *AuthorizationV1Client) SubjectRulesReviews(namespace string) SubjectRulesReviewInterface
type AuthorizationV1Interface ¶
type AuthorizationV1Interface interface {
RESTClient() rest.Interface
ClusterRolesGetter
ClusterRoleBindingsGetter
LocalResourceAccessReviewsGetter
LocalSubjectAccessReviewsGetter
ResourceAccessReviewsGetter
RolesGetter
RoleBindingsGetter
RoleBindingRestrictionsGetter
SelfSubjectRulesReviewsGetter
SubjectAccessReviewsGetter
SubjectRulesReviewsGetter
}
type ClusterRoleBindingExpansion ¶
type ClusterRoleBindingExpansion interface{}
type ClusterRoleBindingInterface ¶
type ClusterRoleBindingInterface interface {
Create(ctx context.Context, clusterRoleBinding *authorizationv1.ClusterRoleBinding, opts metav1.CreateOptions) (*authorizationv1.ClusterRoleBinding, error)
Update(ctx context.Context, clusterRoleBinding *authorizationv1.ClusterRoleBinding, opts metav1.UpdateOptions) (*authorizationv1.ClusterRoleBinding, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*authorizationv1.ClusterRoleBinding, error)
List(ctx context.Context, opts metav1.ListOptions) (*authorizationv1.ClusterRoleBindingList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *authorizationv1.ClusterRoleBinding, err error)
Apply(ctx context.Context, clusterRoleBinding *applyconfigurationsauthorizationv1.ClusterRoleBindingApplyConfiguration, opts metav1.ApplyOptions) (result *authorizationv1.ClusterRoleBinding, err error)
ClusterRoleBindingExpansion
}
ClusterRoleBindingInterface has methods to work with ClusterRoleBinding resources.
type ClusterRoleBindingsGetter ¶
type ClusterRoleBindingsGetter interface {
ClusterRoleBindings() ClusterRoleBindingInterface
}
ClusterRoleBindingsGetter has a method to return a ClusterRoleBindingInterface. A group's client should implement this interface.
type ClusterRoleExpansion ¶
type ClusterRoleExpansion interface{}
type ClusterRoleInterface ¶
type ClusterRoleInterface interface {
Create(ctx context.Context, clusterRole *authorizationv1.ClusterRole, opts metav1.CreateOptions) (*authorizationv1.ClusterRole, error)
Update(ctx context.Context, clusterRole *authorizationv1.ClusterRole, opts metav1.UpdateOptions) (*authorizationv1.ClusterRole, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*authorizationv1.ClusterRole, error)
List(ctx context.Context, opts metav1.ListOptions) (*authorizationv1.ClusterRoleList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *authorizationv1.ClusterRole, err error)
Apply(ctx context.Context, clusterRole *applyconfigurationsauthorizationv1.ClusterRoleApplyConfiguration, opts metav1.ApplyOptions) (result *authorizationv1.ClusterRole, err error)
ClusterRoleExpansion
}
ClusterRoleInterface has methods to work with ClusterRole resources.
type ClusterRolesGetter ¶
type ClusterRolesGetter interface {
ClusterRoles() ClusterRoleInterface
}
ClusterRolesGetter has a method to return a ClusterRoleInterface. A group's client should implement this interface.
type LocalResourceAccessReviewExpansion ¶
type LocalResourceAccessReviewExpansion interface{}
type LocalResourceAccessReviewInterface ¶
type LocalResourceAccessReviewInterface interface {
Create(ctx context.Context, localResourceAccessReview *authorizationv1.LocalResourceAccessReview, opts metav1.CreateOptions) (*authorizationv1.ResourceAccessReviewResponse, error)
LocalResourceAccessReviewExpansion
}
LocalResourceAccessReviewInterface has methods to work with LocalResourceAccessReview resources.
type LocalResourceAccessReviewsGetter ¶
type LocalResourceAccessReviewsGetter interface {
LocalResourceAccessReviews(namespace string) LocalResourceAccessReviewInterface
}
LocalResourceAccessReviewsGetter has a method to return a LocalResourceAccessReviewInterface. A group's client should implement this interface.
type LocalSubjectAccessReviewExpansion ¶
type LocalSubjectAccessReviewExpansion interface{}
type LocalSubjectAccessReviewInterface ¶
type LocalSubjectAccessReviewInterface interface {
Create(ctx context.Context, localSubjectAccessReview *authorizationv1.LocalSubjectAccessReview, opts metav1.CreateOptions) (*authorizationv1.SubjectAccessReviewResponse, error)
LocalSubjectAccessReviewExpansion
}
LocalSubjectAccessReviewInterface has methods to work with LocalSubjectAccessReview resources.
type LocalSubjectAccessReviewsGetter ¶
type LocalSubjectAccessReviewsGetter interface {
LocalSubjectAccessReviews(namespace string) LocalSubjectAccessReviewInterface
}
LocalSubjectAccessReviewsGetter has a method to return a LocalSubjectAccessReviewInterface. A group's client should implement this interface.
type ResourceAccessReviewExpansion ¶
type ResourceAccessReviewExpansion interface{}
type ResourceAccessReviewInterface ¶
type ResourceAccessReviewInterface interface {
Create(ctx context.Context, resourceAccessReview *authorizationv1.ResourceAccessReview, opts metav1.CreateOptions) (*authorizationv1.ResourceAccessReviewResponse, error)
ResourceAccessReviewExpansion
}
ResourceAccessReviewInterface has methods to work with ResourceAccessReview resources.
type ResourceAccessReviewsGetter ¶
type ResourceAccessReviewsGetter interface {
ResourceAccessReviews() ResourceAccessReviewInterface
}
ResourceAccessReviewsGetter has a method to return a ResourceAccessReviewInterface. A group's client should implement this interface.
type RoleBindingExpansion ¶
type RoleBindingExpansion interface{}
type RoleBindingInterface ¶
type RoleBindingInterface interface {
Create(ctx context.Context, roleBinding *authorizationv1.RoleBinding, opts metav1.CreateOptions) (*authorizationv1.RoleBinding, error)
Update(ctx context.Context, roleBinding *authorizationv1.RoleBinding, opts metav1.UpdateOptions) (*authorizationv1.RoleBinding, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*authorizationv1.RoleBinding, error)
List(ctx context.Context, opts metav1.ListOptions) (*authorizationv1.RoleBindingList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *authorizationv1.RoleBinding, err error)
Apply(ctx context.Context, roleBinding *applyconfigurationsauthorizationv1.RoleBindingApplyConfiguration, opts metav1.ApplyOptions) (result *authorizationv1.RoleBinding, err error)
RoleBindingExpansion
}
RoleBindingInterface has methods to work with RoleBinding resources.
type RoleBindingRestrictionExpansion ¶
type RoleBindingRestrictionExpansion interface{}
type RoleBindingRestrictionInterface ¶
type RoleBindingRestrictionInterface interface {
Create(ctx context.Context, roleBindingRestriction *authorizationv1.RoleBindingRestriction, opts metav1.CreateOptions) (*authorizationv1.RoleBindingRestriction, error)
Update(ctx context.Context, roleBindingRestriction *authorizationv1.RoleBindingRestriction, opts metav1.UpdateOptions) (*authorizationv1.RoleBindingRestriction, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*authorizationv1.RoleBindingRestriction, error)
List(ctx context.Context, opts metav1.ListOptions) (*authorizationv1.RoleBindingRestrictionList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *authorizationv1.RoleBindingRestriction, err error)
Apply(ctx context.Context, roleBindingRestriction *applyconfigurationsauthorizationv1.RoleBindingRestrictionApplyConfiguration, opts metav1.ApplyOptions) (result *authorizationv1.RoleBindingRestriction, err error)
RoleBindingRestrictionExpansion
}
RoleBindingRestrictionInterface has methods to work with RoleBindingRestriction resources.
type RoleBindingRestrictionsGetter ¶
type RoleBindingRestrictionsGetter interface {
RoleBindingRestrictions(namespace string) RoleBindingRestrictionInterface
}
RoleBindingRestrictionsGetter has a method to return a RoleBindingRestrictionInterface. A group's client should implement this interface.
type RoleBindingsGetter ¶
type RoleBindingsGetter interface {
RoleBindings(namespace string) RoleBindingInterface
}
RoleBindingsGetter has a method to return a RoleBindingInterface. A group's client should implement this interface.
type RoleExpansion ¶
type RoleExpansion interface{}
type RoleInterface ¶
type RoleInterface interface {
Create(ctx context.Context, role *authorizationv1.Role, opts metav1.CreateOptions) (*authorizationv1.Role, error)
Update(ctx context.Context, role *authorizationv1.Role, opts metav1.UpdateOptions) (*authorizationv1.Role, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*authorizationv1.Role, error)
List(ctx context.Context, opts metav1.ListOptions) (*authorizationv1.RoleList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *authorizationv1.Role, err error)
Apply(ctx context.Context, role *applyconfigurationsauthorizationv1.RoleApplyConfiguration, opts metav1.ApplyOptions) (result *authorizationv1.Role, err error)
RoleExpansion
}
RoleInterface has methods to work with Role resources.
type RolesGetter ¶
type RolesGetter interface {
Roles(namespace string) RoleInterface
}
RolesGetter has a method to return a RoleInterface. A group's client should implement this interface.
type SelfSubjectRulesReviewExpansion ¶
type SelfSubjectRulesReviewExpansion interface{}
type SelfSubjectRulesReviewInterface ¶
type SelfSubjectRulesReviewInterface interface {
Create(ctx context.Context, selfSubjectRulesReview *authorizationv1.SelfSubjectRulesReview, opts metav1.CreateOptions) (*authorizationv1.SelfSubjectRulesReview, error)
SelfSubjectRulesReviewExpansion
}
SelfSubjectRulesReviewInterface has methods to work with SelfSubjectRulesReview resources.
type SelfSubjectRulesReviewsGetter ¶
type SelfSubjectRulesReviewsGetter interface {
SelfSubjectRulesReviews(namespace string) SelfSubjectRulesReviewInterface
}
SelfSubjectRulesReviewsGetter has a method to return a SelfSubjectRulesReviewInterface. A group's client should implement this interface.
type SubjectAccessReviewExpansion ¶
type SubjectAccessReviewExpansion interface{}
type SubjectAccessReviewInterface ¶
type SubjectAccessReviewInterface interface {
Create(ctx context.Context, subjectAccessReview *authorizationv1.SubjectAccessReview, opts metav1.CreateOptions) (*authorizationv1.SubjectAccessReviewResponse, error)
SubjectAccessReviewExpansion
}
SubjectAccessReviewInterface has methods to work with SubjectAccessReview resources.
type SubjectAccessReviewsGetter ¶
type SubjectAccessReviewsGetter interface {
SubjectAccessReviews() SubjectAccessReviewInterface
}
SubjectAccessReviewsGetter has a method to return a SubjectAccessReviewInterface. A group's client should implement this interface.
type SubjectRulesReviewExpansion ¶
type SubjectRulesReviewExpansion interface{}
type SubjectRulesReviewInterface ¶
type SubjectRulesReviewInterface interface {
Create(ctx context.Context, subjectRulesReview *authorizationv1.SubjectRulesReview, opts metav1.CreateOptions) (*authorizationv1.SubjectRulesReview, error)
SubjectRulesReviewExpansion
}
SubjectRulesReviewInterface has methods to work with SubjectRulesReview resources.
type SubjectRulesReviewsGetter ¶
type SubjectRulesReviewsGetter interface {
SubjectRulesReviews(namespace string) SubjectRulesReviewInterface
}
SubjectRulesReviewsGetter has a method to return a SubjectRulesReviewInterface. A group's client should implement this interface.