v1

package
v0.0.0-...-ddca5e0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 10, 2026 License: Apache-2.0 Imports: 11 Imported by: 254

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFilteredImageInformer

func NewFilteredImageInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredImageInformer constructs a new informer for Image type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredImageStreamInformer

func NewFilteredImageStreamInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredImageStreamInformer constructs a new informer for ImageStream type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewImageInformer

func NewImageInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewImageInformer constructs a new informer for Image type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewImageInformerWithOptions

func NewImageInformerWithOptions(client versioned.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewImageInformerWithOptions constructs a new informer for Image type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewImageStreamInformer

func NewImageStreamInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewImageStreamInformer constructs a new informer for ImageStream type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewImageStreamInformerWithOptions

func NewImageStreamInformerWithOptions(client versioned.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewImageStreamInformerWithOptions constructs a new informer for ImageStream type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type ImageInformer

type ImageInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() imagev1.ImageLister
}

ImageInformer provides access to a shared informer and lister for Images.

type ImageStreamInformer

type ImageStreamInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() imagev1.ImageStreamLister
}

ImageStreamInformer provides access to a shared informer and lister for ImageStreams.

type Interface

type Interface interface {
	// Images returns a ImageInformer.
	Images() ImageInformer
	// ImageStreams returns a ImageStreamInformer.
	ImageStreams() ImageStreamInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

Jump to