Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AppliedClusterResourceQuotaLister ¶
type AppliedClusterResourceQuotaLister interface {
// List lists all AppliedClusterResourceQuotas in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*quotav1.AppliedClusterResourceQuota, err error)
// AppliedClusterResourceQuotas returns an object that can list and get AppliedClusterResourceQuotas.
AppliedClusterResourceQuotas(namespace string) AppliedClusterResourceQuotaNamespaceLister
AppliedClusterResourceQuotaListerExpansion
}
AppliedClusterResourceQuotaLister helps list AppliedClusterResourceQuotas. All objects returned here must be treated as read-only.
func NewAppliedClusterResourceQuotaLister ¶
func NewAppliedClusterResourceQuotaLister(indexer cache.Indexer) AppliedClusterResourceQuotaLister
NewAppliedClusterResourceQuotaLister returns a new AppliedClusterResourceQuotaLister.
type AppliedClusterResourceQuotaListerExpansion ¶
type AppliedClusterResourceQuotaListerExpansion interface{}
AppliedClusterResourceQuotaListerExpansion allows custom methods to be added to AppliedClusterResourceQuotaLister.
type AppliedClusterResourceQuotaNamespaceLister ¶
type AppliedClusterResourceQuotaNamespaceLister interface {
// List lists all AppliedClusterResourceQuotas in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*quotav1.AppliedClusterResourceQuota, err error)
// Get retrieves the AppliedClusterResourceQuota from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*quotav1.AppliedClusterResourceQuota, error)
AppliedClusterResourceQuotaNamespaceListerExpansion
}
AppliedClusterResourceQuotaNamespaceLister helps list and get AppliedClusterResourceQuotas. All objects returned here must be treated as read-only.
type AppliedClusterResourceQuotaNamespaceListerExpansion ¶
type AppliedClusterResourceQuotaNamespaceListerExpansion interface{}
AppliedClusterResourceQuotaNamespaceListerExpansion allows custom methods to be added to AppliedClusterResourceQuotaNamespaceLister.
type ClusterResourceQuotaLister ¶
type ClusterResourceQuotaLister interface {
// List lists all ClusterResourceQuotas in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*quotav1.ClusterResourceQuota, err error)
// Get retrieves the ClusterResourceQuota from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*quotav1.ClusterResourceQuota, error)
ClusterResourceQuotaListerExpansion
}
ClusterResourceQuotaLister helps list ClusterResourceQuotas. All objects returned here must be treated as read-only.
func NewClusterResourceQuotaLister ¶
func NewClusterResourceQuotaLister(indexer cache.Indexer) ClusterResourceQuotaLister
NewClusterResourceQuotaLister returns a new ClusterResourceQuotaLister.
type ClusterResourceQuotaListerExpansion ¶
type ClusterResourceQuotaListerExpansion interface{}
ClusterResourceQuotaListerExpansion allows custom methods to be added to ClusterResourceQuotaLister.