Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type PodSecurityPolicyReviewExpansion
- type PodSecurityPolicyReviewInterface
- type PodSecurityPolicyReviewsGetter
- type PodSecurityPolicySelfSubjectReviewExpansion
- type PodSecurityPolicySelfSubjectReviewInterface
- type PodSecurityPolicySelfSubjectReviewsGetter
- type PodSecurityPolicySubjectReviewExpansion
- type PodSecurityPolicySubjectReviewInterface
- type PodSecurityPolicySubjectReviewsGetter
- type RangeAllocationExpansion
- type RangeAllocationInterface
- type RangeAllocationsGetter
- type SecurityContextConstraintsExpansion
- type SecurityContextConstraintsGetter
- type SecurityContextConstraintsInterface
- type SecurityV1Client
- func (c *SecurityV1Client) PodSecurityPolicyReviews(namespace string) PodSecurityPolicyReviewInterface
- func (c *SecurityV1Client) PodSecurityPolicySelfSubjectReviews(namespace string) PodSecurityPolicySelfSubjectReviewInterface
- func (c *SecurityV1Client) PodSecurityPolicySubjectReviews(namespace string) PodSecurityPolicySubjectReviewInterface
- func (c *SecurityV1Client) RESTClient() rest.Interface
- func (c *SecurityV1Client) RangeAllocations() RangeAllocationInterface
- func (c *SecurityV1Client) SecurityContextConstraints() SecurityContextConstraintsInterface
- type SecurityV1Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PodSecurityPolicyReviewExpansion ¶
type PodSecurityPolicyReviewExpansion interface{}
type PodSecurityPolicyReviewInterface ¶
type PodSecurityPolicyReviewInterface interface {
Create(ctx context.Context, podSecurityPolicyReview *securityv1.PodSecurityPolicyReview, opts metav1.CreateOptions) (*securityv1.PodSecurityPolicyReview, error)
PodSecurityPolicyReviewExpansion
}
PodSecurityPolicyReviewInterface has methods to work with PodSecurityPolicyReview resources.
type PodSecurityPolicyReviewsGetter ¶
type PodSecurityPolicyReviewsGetter interface {
PodSecurityPolicyReviews(namespace string) PodSecurityPolicyReviewInterface
}
PodSecurityPolicyReviewsGetter has a method to return a PodSecurityPolicyReviewInterface. A group's client should implement this interface.
type PodSecurityPolicySelfSubjectReviewExpansion ¶
type PodSecurityPolicySelfSubjectReviewExpansion interface{}
type PodSecurityPolicySelfSubjectReviewInterface ¶
type PodSecurityPolicySelfSubjectReviewInterface interface {
Create(ctx context.Context, podSecurityPolicySelfSubjectReview *securityv1.PodSecurityPolicySelfSubjectReview, opts metav1.CreateOptions) (*securityv1.PodSecurityPolicySelfSubjectReview, error)
PodSecurityPolicySelfSubjectReviewExpansion
}
PodSecurityPolicySelfSubjectReviewInterface has methods to work with PodSecurityPolicySelfSubjectReview resources.
type PodSecurityPolicySelfSubjectReviewsGetter ¶
type PodSecurityPolicySelfSubjectReviewsGetter interface {
PodSecurityPolicySelfSubjectReviews(namespace string) PodSecurityPolicySelfSubjectReviewInterface
}
PodSecurityPolicySelfSubjectReviewsGetter has a method to return a PodSecurityPolicySelfSubjectReviewInterface. A group's client should implement this interface.
type PodSecurityPolicySubjectReviewExpansion ¶
type PodSecurityPolicySubjectReviewExpansion interface{}
type PodSecurityPolicySubjectReviewInterface ¶
type PodSecurityPolicySubjectReviewInterface interface {
Create(ctx context.Context, podSecurityPolicySubjectReview *securityv1.PodSecurityPolicySubjectReview, opts metav1.CreateOptions) (*securityv1.PodSecurityPolicySubjectReview, error)
PodSecurityPolicySubjectReviewExpansion
}
PodSecurityPolicySubjectReviewInterface has methods to work with PodSecurityPolicySubjectReview resources.
type PodSecurityPolicySubjectReviewsGetter ¶
type PodSecurityPolicySubjectReviewsGetter interface {
PodSecurityPolicySubjectReviews(namespace string) PodSecurityPolicySubjectReviewInterface
}
PodSecurityPolicySubjectReviewsGetter has a method to return a PodSecurityPolicySubjectReviewInterface. A group's client should implement this interface.
type RangeAllocationExpansion ¶
type RangeAllocationExpansion interface{}
type RangeAllocationInterface ¶
type RangeAllocationInterface interface {
Create(ctx context.Context, rangeAllocation *securityv1.RangeAllocation, opts metav1.CreateOptions) (*securityv1.RangeAllocation, error)
Update(ctx context.Context, rangeAllocation *securityv1.RangeAllocation, opts metav1.UpdateOptions) (*securityv1.RangeAllocation, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*securityv1.RangeAllocation, error)
List(ctx context.Context, opts metav1.ListOptions) (*securityv1.RangeAllocationList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *securityv1.RangeAllocation, err error)
Apply(ctx context.Context, rangeAllocation *applyconfigurationssecurityv1.RangeAllocationApplyConfiguration, opts metav1.ApplyOptions) (result *securityv1.RangeAllocation, err error)
RangeAllocationExpansion
}
RangeAllocationInterface has methods to work with RangeAllocation resources.
type RangeAllocationsGetter ¶
type RangeAllocationsGetter interface {
RangeAllocations() RangeAllocationInterface
}
RangeAllocationsGetter has a method to return a RangeAllocationInterface. A group's client should implement this interface.
type SecurityContextConstraintsExpansion ¶
type SecurityContextConstraintsExpansion interface{}
type SecurityContextConstraintsGetter ¶
type SecurityContextConstraintsGetter interface {
SecurityContextConstraints() SecurityContextConstraintsInterface
}
SecurityContextConstraintsGetter has a method to return a SecurityContextConstraintsInterface. A group's client should implement this interface.
type SecurityContextConstraintsInterface ¶
type SecurityContextConstraintsInterface interface {
Create(ctx context.Context, securityContextConstraints *securityv1.SecurityContextConstraints, opts metav1.CreateOptions) (*securityv1.SecurityContextConstraints, error)
Update(ctx context.Context, securityContextConstraints *securityv1.SecurityContextConstraints, opts metav1.UpdateOptions) (*securityv1.SecurityContextConstraints, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*securityv1.SecurityContextConstraints, error)
List(ctx context.Context, opts metav1.ListOptions) (*securityv1.SecurityContextConstraintsList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *securityv1.SecurityContextConstraints, err error)
Apply(ctx context.Context, securityContextConstraints *applyconfigurationssecurityv1.SecurityContextConstraintsApplyConfiguration, opts metav1.ApplyOptions) (result *securityv1.SecurityContextConstraints, err error)
SecurityContextConstraintsExpansion
}
SecurityContextConstraintsInterface has methods to work with SecurityContextConstraints resources.
type SecurityV1Client ¶
type SecurityV1Client struct {
// contains filtered or unexported fields
}
SecurityV1Client is used to interact with features provided by the security.openshift.io group.
func New ¶
func New(c rest.Interface) *SecurityV1Client
New creates a new SecurityV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SecurityV1Client, error)
NewForConfig creates a new SecurityV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new SecurityV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SecurityV1Client
NewForConfigOrDie creates a new SecurityV1Client for the given config and panics if there is an error in the config.
func (*SecurityV1Client) PodSecurityPolicyReviews ¶
func (c *SecurityV1Client) PodSecurityPolicyReviews(namespace string) PodSecurityPolicyReviewInterface
func (*SecurityV1Client) PodSecurityPolicySelfSubjectReviews ¶
func (c *SecurityV1Client) PodSecurityPolicySelfSubjectReviews(namespace string) PodSecurityPolicySelfSubjectReviewInterface
func (*SecurityV1Client) PodSecurityPolicySubjectReviews ¶
func (c *SecurityV1Client) PodSecurityPolicySubjectReviews(namespace string) PodSecurityPolicySubjectReviewInterface
func (*SecurityV1Client) RESTClient ¶
func (c *SecurityV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*SecurityV1Client) RangeAllocations ¶
func (c *SecurityV1Client) RangeAllocations() RangeAllocationInterface
func (*SecurityV1Client) SecurityContextConstraints ¶
func (c *SecurityV1Client) SecurityContextConstraints() SecurityContextConstraintsInterface
type SecurityV1Interface ¶
type SecurityV1Interface interface {
RESTClient() rest.Interface
PodSecurityPolicyReviewsGetter
PodSecurityPolicySelfSubjectReviewsGetter
PodSecurityPolicySubjectReviewsGetter
RangeAllocationsGetter
SecurityContextConstraintsGetter
}